//
//  IZegoAvatarView.h
//  ZegoAvatar
//
//  Created by justinsong on 2021/12/3.
//
//
//  ZegoAvatarView.h
//  virtual
//
//  Created by justinsong on 2021/11/17.
//

#pragma once
#import <UIKit/UIKit.h>
#import "ZegoTypes.h"
#import "IZegoCharacter.h"

NS_ASSUME_NONNULL_BEGIN

#pragma mark - IZegoAvatarView

@protocol IZegoAvatarView <NSObject>

@required

/// 设置 View 背景图片
@property (nonatomic, strong) UIImage *backgroundImage;

/// 设置 View 的角色
/// 
/// @param character character
- (void)setCharacter:(id<IZegoCharacter>)character;

/// 设置 View 的角色
///
/// Description: callback 设置角色后，在绘制角色的第一帧完成时回调。
///
/// @param character character
/// @param callback  callback
- (void)setCharacter:(id<IZegoCharacter>)character callback:(ZegoAvatarCharacterCallback)callback;

/// 移除 View 的角色
///
/// @param character character
- (void)removeCharacter:(id<IZegoCharacter>)character;

/// 移除 View 的所有角色
- (void)removeAllCharacter;

/// 暂停 View 的渲染
- (void)pause;

/// 恢复 View 的渲染
- (void)resume;

/// 截取 View 视图当前帧图片
///
/// @return View 视图当前帧图片
- (UIImage *)captureScreenshot;

/// 录制 View 的视频
///
/// Description:
///   recordConfig.videoPath 路径下有同名文件会被覆盖。
///   onStartRecordCallback 在开始录制时回调，只回调一次。
///
/// @param recordConfig 录制参数配置
/// @param onStartRecordCallback callback
- (BOOL)startRecord:(ZegoRecordConfig *)recordConfig onStartRecordCallback:(void (^)(NSInteger errorCode, NSString *info))onStartRecordCallback;

/// 结束 View 的录制
///
/// Description: onStopRecordCallback 在结束录制后回调。
///
/// @param onStopRecordCallback callback
- (void)stopRecord:(void (^)(void))onStopRecordCallback;

/// 暂停录制
///
/// Description: 录制视频中暂停和恢复, 会带来很多不可预见的兼容性问题, 未来版本将废弃该接口。
- (void)pauseRecord;

/// 恢复录制
///
/// Description: 录制视频中暂停和恢复, 会带来很多不可预见的兼容性问题, 未来版本将废弃该接口。
- (void)resumeRecord;

/// 展示 View 中角色的影子
///
/// Description: 默认不展示。
///
/// @param show show
- (void)showShadowFloor:(BOOL)show;

/// 是否能缩放角色
///
/// Description: 默认开启。
///
/// @param enable enable
- (void)enableCameraScale:(BOOL)enable;

/// 是否能旋转角色，默认开启
///
/// Description: 默认开启。
///
/// @param enable enable
- (void)enableCameraRotate:(BOOL)enable;

/// 设置相机机位
///
/// @param cameraName 机位描述
- (void)setCamera:(NSString *)cameraName;

/// 播放多人动画
///
/// Description:
///   将角色动画的绝对路径作为 value ，角色 roleID 作为 key ，放入 map 中。
///   callback 在动画完成后回调。
///
/// @param map map
/// @param callback callback
- (void)playMultiCharacterAnimation:(NSDictionary<NSString *, NSString *> *)map
                           callback:(ZegoAvatarMultiCharacterAnimationCallback)callback;

/// 设置 AvatarView 的纹理监听回调
///
/// Description: 回调 AvatarView 的纹理ID。
///
/// @param callback callback
- (void)setTextureUpdateCallback:(ZegoAvatarViewTextureUpdateCallback)callback;

@end

NS_ASSUME_NONNULL_END
