//
//  IZegoIneractEngine.h
//  ZegoAvatar
//
//  Created by justinsong on 2021/12/3.
//

#pragma once

#import <UIKit/UIKit.h>
#import "ZegoTypes.h"
#import "AudioDataDelegate.h"
#import "VideoDataDelegate.h"
#import "IZegoCharacter.h"

#pragma mark - IZegoInteractEngine

/// SDK 互动引擎协议
@protocol IZegoInteractEngine <NSObject>

@required

/// 表情检测方向
@property (nonatomic, assign) UIInterfaceOrientation orientation;

/// 获取当前表情检测模式
///
/// @return 表情检测模式
- (ZegoExpressionDetectMode)getExpressionDetectMode;

/// 开始表情检测
///
/// Description:
///   ZegoExpressionDetectModeCamera: 使用摄像头采集的画面推理；ZegoExpressionDetectModeAudio: 使用麦克风采集的音频推理。
///   回调 AI 引擎推理的表情数据。
///
/// @param detectMode detectMode
/// @param callback callback
/// @return 开启表情检测是否成功
- (BOOL)startDetectExpression:(ZegoExpressionDetectMode)detectMode callback:(ZegoAvatarExpressionCallback)callback;

/// 停止表情检测
- (void)stopDetectExpression;

/// 判断表情是否在检测中
///
/// @return 表情是否在检测中
- (BOOL)isExpressDetecting;

/// 获取当前肢体驱动检测模式
- (ZegoPoseDetectMode)getPoseDetectMode;

/// 开始肢体驱动检测
///
/// Description: Q版角色暂不支持肢体驱动。
///
/// @param detectMode detectMode
/// @param callback callback
/// @return 开启肢体驱动检测是否成功
- (BOOL)startDetectPose:(ZegoPoseDetectMode)detectMode callback:(ZegoAvatarPoseCallback)callback;

/// 停止肢体驱动检测
- (void)stopDetectPose;

/// 判断是否在肢体驱动检测中
///
/// @return 是否在肢体驱动检测中
- (BOOL)isPoseDetecting;

/// 开始手势识别
///
/// Description: 回调 AI 引擎推理的手势类型。
///
/// @param callback callback
/// @return 开启手势识别是否成功
- (BOOL)startDetectHandClassify:(ZegoAvatarHandClassifyCallback)callback;

/// 停止手势识别
- (void)stopDetectHandClassify;

/// 检测图片的人脸特征
///
/// @param image image
/// @return 人脸特征数据
- (ZegoFaceFeature *)detectFaceFeature:(UIImage *)image;

/// 设置自定义的音频数据采集代理
///
/// @param delegate delegate
- (void)setCustomAudioDelegate:(AudioDataDelegate *)delegate;

/// 设置自定义的视频数据采集代理
///
/// @param delegate delegate
- (void)setCustomVideoDelegate:(VideoDataDelegate *)delegate;

/// 设置监听摄像头纹理回调
///
/// Description: 在调用 [startDetectHandClassify:] 或者 [startDetectPose] 后回调。
///
/// @param callback callback
- (void)setOnCameraFrameCallback:(ZegoAvatarCameraFrameCallback)callback;

@end

